Learn R Programming

adehabitatHS (version 0.3.12)

domain: Estimation of the Potential Distribution of a Species

Description

domain uses the DOMAIN algorithm to estimate the potential distribution of a species based on a list of species occurrences and on maps of the area.

Usage

domain(x, pts, type = c("value", "potential"), thresh = 0.95)

Arguments

x

an object of class SpatialPixelsDataFrame

pts

a data frame giving the x and y coordinates of the species occurrences.

type

a character string. The "value" of the suitability may be returned or the "potential" area of distribution

thresh

if value = "potential", a threshold value should be supplied for the suitability (by default 0.95)

Value

Returns an object of class SpatialPixelsDataFrame.

Warning

domain is restricted to maps containing only numerical variables (i.e. no factors).

Details

This function implements the DOMAIN algorithm described in Carpenter et al. (1993).

References

Carpenter, G., Gillison, A.N. and Winter, J. (1993) DOMAIN: a flexible modelling procedure for mapping potential distributions of plants and animals. Biodiversity and conservation, 2, 667--680.

See Also

mahasuhab

Examples

Run this code
# NOT RUN {
## Preparation of the data
data(lynxjura)
map <- lynxjura$map
pts <- lynxjura$locs

## View of the data
image(map)
title(main="Elevation")
points(pts, pch = 3)

## Estimation of habitat suitability map
hsm <- domain(map, pts)

image(hsm, col = grey((1:256)/256))
contour(hsm, add = TRUE)

## Lighter areas are the most used areas

## Potential distribution
hsm <- domain(map, pts, type = "potential", thresh = 0.98)
image(hsm, col = "orange")
title(main = "Habitat suitability map")
points(pts, pch = 3)

# }

Run the code above in your browser using DataLab